BehaviorData class

Behavior data for monitoring

Constructors

BehaviorData({required int apiHits, required int screenTouches, required int appLaunches, required DateTime timestamp, Map<String, dynamic> additionalData = const {}})
const

Properties

additionalData Map<String, dynamic>
final
apiHits int
final
appLaunches int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenTouches int
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited