BiometricConfig class

Biometric Configuration

Constructors

BiometricConfig({BiometricType preferredType = BiometricType.fingerprint, bool allowFallback = true, Duration sessionTimeout = const Duration(minutes: 30), bool requireBiometricForSensitiveData = true, List<String> sensitiveOperations = const ['secureStore', 'secureRetrieve', 'encryptData']})
const
BiometricConfig.fromJson(Map<String, dynamic> json)
factory

Properties

allowFallback bool
final
hashCode int
The hash code for this object.
no setterinherited
preferredType BiometricType
final
requireBiometricForSensitiveData bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensitiveOperations List<String>
final
sessionTimeout Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited