BiometricResult class

Biometric authentication result

Constructors

BiometricResult({required bool success, required BiometricType type, String? errorMessage, Map<String, dynamic>? metadata})
const

Properties

errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final
type BiometricType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited