DeviceSecurityStatus class

Device security status

Constructors

DeviceSecurityStatus({required bool isRooted, required bool isJailbroken, required bool isEmulator, required bool isDebuggerAttached, required bool hasProxy, required bool hasVPN, required bool isScreenCaptureBlocked, required bool isSSLValid, required bool isBiometricAvailable, required bool isCodeObfuscated, required bool isDeveloperModeEnabled, required bool isUsbCableAttached, required double riskScore, required bool isSecure, required List<SecurityThreat> activeThreats})
const
DeviceSecurityStatus.fromJson(Map<String, dynamic> json)
factory

Properties

activeThreats List<SecurityThreat>
final
hashCode int
The hash code for this object.
no setterinherited
hasProxy bool
final
hasVPN bool
final
isBiometricAvailable bool
final
isCodeObfuscated bool
final
isDebuggerAttached bool
final
isDeveloperModeEnabled bool
final
isEmulator bool
final
isJailbroken bool
final
isRooted bool
final
isScreenCaptureBlocked bool
final
isSecure bool
final
isSSLValid bool
final
isUsbCableAttached bool
final
riskScore double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isRooted, bool? isJailbroken, bool? isEmulator, bool? isDebuggerAttached, bool? hasProxy, bool? hasVPN, bool? isScreenCaptureBlocked, bool? isSSLValid, bool? isBiometricAvailable, bool? isCodeObfuscated, bool? isDeveloperModeEnabled, bool? isUsbCableAttached, double? riskScore, bool? isSecure, List<SecurityThreat>? activeThreats}) DeviceSecurityStatus
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited