ObfuscationConfig class

Code Obfuscation Configuration

Constructors

ObfuscationConfig({bool enableDartObfuscation = true, bool enableStringObfuscation = true, bool enableClassObfuscation = true, bool enableMethodObfuscation = true, bool enableDebugPrintStripping = true, bool enableStackTraceObfuscation = true, Map<String, String> customObfuscationRules = const {}})
const
ObfuscationConfig.fromJson(Map<String, dynamic> json)
factory

Properties

customObfuscationRules Map<String, String>
final
enableClassObfuscation bool
final
enableDartObfuscation bool
final
enableDebugPrintStripping bool
final
enableMethodObfuscation bool
final
enableStackTraceObfuscation bool
final
enableStringObfuscation bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited