SecurityThreat class

Security threat information

Constructors

SecurityThreat({required SecurityThreatType type, required SecurityThreatLevel level, required String description, required DateTime timestamp, Map<String, dynamic>? metadata})
const
SecurityThreat.fromJson(Map<String, dynamic> json)
factory

Properties

description String
final
hashCode int
The hash code for this object.
no setterinherited
level SecurityThreatLevel
final
metadata Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final
type SecurityThreatType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited