UltraSecureFlutterKitPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • UltraSecureFlutterKitPlatform
Implementers

Constructors

UltraSecureFlutterKitPlatform()
Constructs a UltraSecureFlutterKitPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyAntiTampering() Future<void>
configureSSLPinning(List<String> certificates, List<String> publicKeys) Future<void>
disableScreenCaptureProtection() Future<void>
enableNetworkMonitoring() Future<void>
enableRealTimeMonitoring() Future<void>
enableScreenCaptureProtection() Future<void>
enableSecureFlag() Future<void>
getAppSignature() Future<String>
getDeviceFingerprint() Future<String>
getPlatformVersion() Future<String?>
getUnexpectedCertificates() Future<List<String>>
getUsbConnectionStatus() Future<Map<String, dynamic>>
Get USB connection status details
hasProxySettings() Future<bool>
hasVPNConnection() Future<bool>
isDebuggerAttached() Future<bool>
isDeveloperModeEnabled() Future<bool>
isEmulator() Future<bool>
isJailbroken() Future<bool>
isRooted() Future<bool>
isScreenCaptureBlocked() Future<bool>
isUsbCableAttached() Future<bool>
Check if USB cable is attached
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openDeveloperOptionsSettings() Future<void>
preventReverseEngineering() Future<void>
toString() String
A string representation of this object.
inherited
verifyAppIntegrity() Future<bool>
verifySSLPinning(String url) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance UltraSecureFlutterKitPlatform
Default instance of UltraSecureFlutterKitPlatform to use.
getter/setter pair