UltraSecureFlutterKitWeb class

Web implementation of UltraSecureFlutterKit

Inheritance

Constructors

UltraSecureFlutterKitWeb()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityEventStream → Stream<Map<String, dynamic>>
no setter

Methods

applyAntiTampering() → Future<void>
override
configureSSLPinning(List<String> certificates, List<String> publicKeys) → Future<void>
override
disableScreenCaptureProtection() → Future<void>
override
enableNetworkMonitoring() → Future<void>
override
enableRealTimeMonitoring() → Future<void>
override
enableScreenCaptureProtection() → Future<void>
override
enableSecureFlag() → Future<void>
override
getAppSignature() → Future<String>
override
getBehaviorData() → Map<String, dynamic>
getDeviceFingerprint() → Future<String>
override
getPlatformVersion() → Future<String?>
override
getUnexpectedCertificates() → Future<List<String>>
override
getUsbConnectionStatus() → Future<Map<String, dynamic>>
Get USB connection status details
override
hasProxySettings() → Future<bool>
override
hasVPNConnection() → Future<bool>
override
isDebuggerAttached() → Future<bool>
override
isDeveloperModeEnabled() → Future<bool>
override
isEmulator() → Future<bool>
override
isJailbroken() → Future<bool>
override
isRooted() → Future<bool>
override
isScreenCaptureBlocked() → Future<bool>
override
isUsbCableAttached() → Future<bool>
Check if USB cable is attached
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openDeveloperOptionsSettings() → Future<void>
override
preventReverseEngineering() → Future<void>
override
recordApiHit() → void
recordAppLaunch() → void
recordScreenTouch() → void
toString() → String
A string representation of this object.
inherited
verifyAppIntegrity() → Future<bool>
override
verifySSLPinning(String url) → Future<bool>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(dynamic registrar) → void
Static register method for web plugin registration