SSLPinningConfig class
SSL Pinning Configuration
Constructors
-
SSLPinningConfig({SSLPinningMode mode = SSLPinningMode.strict, List<
String> pinnedCertificates = const [], List<String> pinnedPublicKeys = const [], Duration certificateExpiryCheck = const Duration(days: 30), bool enableFallback = false}) -
const
-
SSLPinningConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- certificateExpiryCheck → Duration
-
final
- enableFallback → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → SSLPinningMode
-
final
-
pinnedCertificates
→ List<
String> -
final
-
pinnedPublicKeys
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited