SecurityThreatType enum
Types of security threats
Values
- rootDetected → const SecurityThreatType
- jailbreakDetected → const SecurityThreatType
- emulatorDetected → const SecurityThreatType
- debuggerDetected → const SecurityThreatType
- screenCaptureAttempted → const SecurityThreatType
- networkTamperingDetected → const SecurityThreatType
- proxyDetected → const SecurityThreatType
- vpnDetected → const SecurityThreatType
- suspiciousBehaviorDetected → const SecurityThreatType
- appTamperingDetected → const SecurityThreatType
- reverseEngineeringDetected → const SecurityThreatType
- dataLeakageDetected → const SecurityThreatType
- fridaDetected → const SecurityThreatType
- xposedDetected → const SecurityThreatType
- mitmAttackDetected → const SecurityThreatType
- certificateMismatch → const SecurityThreatType
- biometricBypassDetected → const SecurityThreatType
- usbCableAttached → const SecurityThreatType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SecurityThreatType> - A constant List of the values in this enum, in order of their declaration.